@@ -203,24 +203,20 @@ static void
 window_update_sensitivity (GooWindow *window)
 {
 	int            n_selected;
-	gboolean       sel_not_null;
 	gboolean       one_file_selected;
 	GooPlayerState state;
 	gboolean       error;
 	gboolean       audio_cd;
 	gboolean       playing;
 	gboolean       paused;
-	gboolean       stopped;
 	gboolean       play_all;
 
 	n_selected        = _gtk_count_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->priv->list_view)));
-	sel_not_null      = n_selected > 0;
 	one_file_selected = n_selected == 1;
 	state             = goo_player_get_state (window->priv->player);
 	error             = ! goo_player_is_audio_cd (window->priv->player) || window->priv->hibernate;
 	playing           = state == GOO_PLAYER_STATE_PLAYING;
 	paused            = state == GOO_PLAYER_STATE_PAUSED;
-	stopped           = state == GOO_PLAYER_STATE_STOPPED;
 	play_all          = g_settings_get_boolean (window->priv->settings_playlist, PREF_PLAYLIST_PLAYALL);
 	audio_cd          = (! error) && (goo_player_get_discid (window->priv->player) != NULL);
 
@@ -1464,15 +1460,11 @@ static void
 window_update_title (GooWindow *window)
 {
 	GooPlayerState  state;
-	gboolean        playing;
 	gboolean        paused;
-	gboolean        stopped;
 	GString        *title;
 
-	state   = goo_player_get_state (window->priv->player);
-	playing = state == GOO_PLAYER_STATE_PLAYING;
-	paused  = state == GOO_PLAYER_STATE_PAUSED;
-	stopped = state == GOO_PLAYER_STATE_STOPPED;
+	state = goo_player_get_state (window->priv->player);
+	paused = state == GOO_PLAYER_STATE_PAUSED;
 
 	title = g_string_new ("");
 
@@ -2421,6 +2413,7 @@ goo_window_construct (GooWindow    *window,
 
 	window->priv->toolbar = toolbar = gtk_ui_manager_get_widget (ui, "/ToolBar");
 	gtk_style_context_add_class (gtk_widget_get_style_context (window->priv->toolbar), GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+	gtk_widget_set_hexpand (toolbar, TRUE);
 	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), TRUE);
 	gth_window_attach_toolbar (GTH_WINDOW (window), 0, window->priv->toolbar);
 
@@ -2506,10 +2499,10 @@ goo_window_construct (GooWindow    *window,
 
 	/**/
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
